### Links

* Source: [www.swpc.noaa.gov](https://www.swpc.noaa.gov/products/aurora-30-minute-forecast)
* Docs: [palewi.re/docs/nws-aurora/](https://palewi.re/docs/nws-aurora/)
* Issues: [github.com/datadesk/nws-aurora/issues](https://github.com/datadesk/nws-aurora/issues)
* Packaging: [pypi.python.org/pypi/nws-aurora](https://pypi.python.org/pypi/nws-aurora)
* Testing: [github.com/datadesk/nws-aurora/actions](https://github.com/datadesk/nws-aurora/actions)
